import React from 'react';
import PropTypes from 'prop-types';
import { Button, Toast } from 'antd-mobile';
import './style.scss';
import acIcon from '../../images/Login/account_icon@2x.png';
import psIcon from '../../images/Login/password_icon@2x.png';
import { wxLogin, login } from '../../api/index';
import UserInfoContext from '../../context/userinfo-context';

export class Index extends React.Component {
  static propTypes = {
    code: PropTypes.string,
    updateUserInfo: PropTypes.func,
  };
  constructor(props, context) {
    super(props, context);
    this.state = {
      account: '',
      password: '',
    };
  }

  componentWillMount() {
    const { setTitle, updateUserInfo } = this.props;
    setTitle('登陆');
    const { code } = this.props;
    if (code) {
      Toast.loading('', 20);
      wxLogin({
        code,
      })
        .then(res => {
          Toast.hide();
          console.log(res);
          const data = res.data;
          const { history } = this.props;
          updateUserInfo(data);
          const location = {
            pathname: '/BindEquipment',
            state: data,
          };
          history.push(location);
        })
        .catch(err => {
          console.log(err);
          Toast.fail(err.msg || '自动登陆失败！');
        });
    }
  }
  changeHandle = (key, e) => {
    this.setState({
      [key]: e.target.value.trim(),
    });
  };
  validate = () => {
    const { account, password } = this.state;
    if (account === '') {
      Toast.fail('请输入账号');
      return false;
    }
    if (password === '') {
      Toast.fail('请输入密码');
      return false;
    }
    return true;
  };
  login = () => {
    if (this.validate()) {
      Toast.loading('', 20);
      const { account, password } = this.state;
      const { updateUserInfo, code } = this.props;
      let entity = code
        ? {
            account,
            password,
            weixinCode: code,
          }
        : {
            account,
            password,
          };
      login(entity)
        .then(res => {
          Toast.hide();
          // console.log(res);
          const data = res.data;
          const { accountCategory } = data;
          const { isSpecialArea } = data;
          const { history } = this.props;
          updateUserInfo({
            ...data,
            position: {
              id: null,
              position: null,
              mode: null,
              isBind: false,
              deviceType: null,
            },
          });
          const location =
          // {
          //   pathname: '/EquipmentSpecialArea',
          //   state: data,
          // };
          isSpecialArea === 1 
          ? {
            pathname: '/EquipmentSpecialArea',
            state: data,
          } :
            accountCategory === 1
              ? {
                  pathname: '/BindEquipment',
                  state: data,
                }
              : {
                  pathname: '/EquipmentTest',
                  state: data,
                };
          history.push(location);
        })
        .catch(err => {
          console.log(err);
          Toast.fail(err.msg || '登陆失败！');
        });
    }
  };
  render() {
    return (
      <div className='appContent Login'>
        <div className='br8 loginBox'>
          <label className='listItem accountItem'>
            <i className='inputIcon'>
              <img src={acIcon} alt='' />
            </i>
            <input
              className='listInput'
              onChange={e => this.changeHandle('account', e)}
              type='text'
              placeholder='请输入运维账号'
              maxLength='10'
            />
          </label>
          <label className='listItem pwdItem'>
            <i className='inputIcon'>
              <img src={psIcon} alt='' />
            </i>
            <input
              className='listInput'
              onChange={e => this.changeHandle('password', e)}
              type='password'
              placeholder='请输入登陆密码'
              maxLength='10'
            />
          </label>
          <Button type='primary' className='login-btn' onClick={this.login}>
            登录
          </Button>
        </div>
      </div>
    );
  }
}

export default props => (
  <UserInfoContext.Consumer>
    {({ updateUserInfo }) => (
      <Index {...props} updateUserInfo={updateUserInfo} />
    )}
  </UserInfoContext.Consumer>
);
