import React from 'react';
import PropTypes from 'prop-types';
import { Button, Toast } from 'antd-mobile';
import './style.scss';
import eqIcon from '../../images/Equipment/equip_number_icon@2x.png';
import locationIcon from '../../images/Equipment/install_position_icon@2x.png';
import UserInfoContext from '../../context/userinfo-context';
import { bindEquipment, unbindEquipment } from '../../api/index';

export class SelectEquipment extends React.Component {
  static propTypes = {
    name: PropTypes.string,
    userinfo: PropTypes.object,
  };
  componentWillMount() {
    const { setTitle } = this.props;
    setTitle('绑定解绑设备');
  }
  goLocation = () => {
    const { history } = this.props;
    const { deviceCode } = this.props.match.params;
    history.push('/Equipment/' + deviceCode + '/Location');
  };
  bindEquipment = () => {
    console.log('bind');
    const { deviceCode } = this.props.match.params;
    const {
      userinfo: { position },
      updateUserInfo,
    } = this.props;
    if (position.id) {
      bindEquipment({
        deviceCode,
        positionId: position.id,
      })
        .then(res => {
          Toast.success('绑定成功' || res.msg);
          updateUserInfo({
            position: {
              ...position,
              isBind: true,
            },
          });
        })
        .catch(err => {
          Toast.fail(err.msg || '绑定位置失败');
        });
    } else {
      Toast.fail('请选择安装位置');
    }
  };
  unbindEquipment = () => {
    console.log('unbind');
    const { deviceCode } = this.props.match.params;
    const {
      userinfo: { position },
      updateUserInfo,
    } = this.props;
    unbindEquipment({
      deviceCode,
      positionId: position.id,
    })
      .then(res => {
        Toast.success('解绑成功' || res.msg);
        updateUserInfo({
          position: {
            ...position,
            id: null,
            position: null,
            isBind: false,
          },
        });
      })
      .catch(err => {
        Toast.fail(err.msg || '请选择安装位置');
      });
  };
  render() {
    const { deviceCode } = this.props.match.params;
    const { position } = this.props.userinfo;
    return (
      <div className='appContent SelectEquipment'>
        <div className='List'>
          <label className='SE-listItem'>
            <div className='SE-inputBox'>
              <i className='inputIcon'>
                <img src={eqIcon} alt='' />
              </i>
              <span className='ellipsis inputText'>设备编号：</span>
            </div>
            <div className='br8 input nobor'>{deviceCode}</div>
          </label>
          <label className='SE-listItem'>
            <div className='SE-inputBox'>
              <i className='inputIcon'>
                <img src={locationIcon} alt='' />
              </i>
              <span className='ellipsis inputText'>选择安装位置：</span>
            </div>
            {position.isBind ? (
              <div className='br8 input'>{position.position}</div>
            ) : (
              <div className='br8 input autoH' onClick={this.goLocation}>
                {position.id ? position.position : '点击选择设备安装位置'}
              </div>
            )}
          </label>
        </div>
        {position.isBind ? (
          <div className='btnBox'>
            <Button className='btn'>绑定设备</Button>
            <Button
              className='btn'
              type='primary'
              onClick={this.unbindEquipment}>
              解绑设备
            </Button>
          </div>
        ) : (
          <div className='btnBox'>
            <Button className='btn' type='primary' onClick={this.bindEquipment}>
              绑定设备
            </Button>
            <Button className='btn'>解绑设备</Button>
          </div>
        )}
      </div>
    );
  }
}

export default props => (
  <UserInfoContext.Consumer>
    {({ userinfo, updateUserInfo }) => (
      <SelectEquipment
        {...props}
        userinfo={userinfo}
        updateUserInfo={updateUserInfo}
      />
    )}
  </UserInfoContext.Consumer>
);
